from __future__ import print_function
import os.path
try:
    from urllib2 import urlopen
    from md5 import md5
except ImportError:
    from urllib.request import urlopen
    from hashlib import md5


class MockOpener(object):
    '''
    Open data for URL from local file.

    For a given URL, instead open a file handle to the matching hash. If that
    does not exist, download the data and save.
    '''
    def __init__(self, cache_dir, force_remote=False):
        self._cacheDir = cache_dir
        self._force = force_remote

    def open(self, url):
        if self._force:
            return urlopen(url)

        digest = md5(url.encode('ascii')).hexdigest()
        print(url, '->', digest)
        cache_file = os.path.join(self._cacheDir, digest)

        try:
            return open(cache_file, 'rb')
        except IOError:
            print("Downloading data for test:", url)

            buf = urlopen(url).read()
            save = open(cache_file, 'wb')
            save.write(buf)
            save.close()

            return open(cache_file, 'rb')
