import requests

from io import BytesIO
from . import __version__

user_agent = 'Siphon (%s)' % __version__


def http_get(url, *args, **kwargs):
    r'''GET a URL using HTTP.

    This is a thin wrapper around ``requests.get`` that sets our custom user agent
    on the request.

    Parameters
    ----------
    url : string
        The URL to request

    args : arbitrary positional arguments
        Additional positional arguments to pass to ``requests.get``.

    kwargs : arbitrary keyword arguments
        Additional keyword arguments to pass to ``requests.get``.

    Returns
    -------
    resp : ``requests.Response``
        The response to the request

    See Also
    --------
    urlopen
    '''

    headers = kwargs.setdefault('headers', {})
    headers['user-agent'] = user_agent
    return requests.get(url, *args, **kwargs)


def urlopen(url, *args, **kwargs):
    r'''GET a file-like object for a URL using HTTP.

    This is a thin wrapper around ``http_get`` that returns a file-like object
    wrapped around the resulting content.

    Parameters
    ----------
    url : string
        The URL to request

    args : arbitrary positional arguments
        Additional positional arguments to pass to ``requests.get``.

    kwargs : arbitrary keyword arguments
        Additional keyword arguments to pass to ``requests.get``.

    Returns
    -------
    fobj : file-like object
        A file-like interface to the content in the response

    See Also
    --------
    http_get
    '''

    return BytesIO(http_get(url, *args, **kwargs).content)
